#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mono-traversable
version:              1.0.21.0
visibility:           public
id:                   mono-traversable-1.0.21.0-CHxbXqM0KN6EUfoafq1cMm
key:                  mono-traversable-1.0.21.0-CHxbXqM0KN6EUfoafq1cMm
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, John Wiegley, Greg Weber
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Type classes for mapping, folding, and traversing monomorphic containers

description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>

category:             Data
abi:                  db98e9bf5e0f4d083c2e408f7ec270d1
exposed:              True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences

hidden-modules:       Paths_mono_traversable
import-dirs:          /usr/lib/ghc-9.6.6/site-local/mono-traversable-1.0.21.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mono-traversable-1.0.21.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mono-traversable-1.0.21.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable
hs-libraries:         HSmono-traversable-1.0.21.0-CHxbXqM0KN6EUfoafq1cMm
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-D2jhP8LVtgFIAnKx76ZNYr
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-ZzaTCzIdz8BWoPLHKXAc8
    vector-0.13.2.0-5VH4z5LB2hn3qUPNgI7cRE
    vector-algorithms-0.9.1.0-KqY60HoSx23HX1LJl4kFIz

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

